@@ -81,7 +81,7 @@ async def openai_generate(request: ImageRequest, api_key: Optional[str] = None,
     )
 
     completion = await client.chat.completions.create(**data)
-    # logger.debug(completion)
+    logger.debug(completion)
     if completion and completion.choices and (revised_prompt := completion.choices[0].message.content.strip()):
         logger.debug(revised_prompt)
 
@@ -109,11 +109,7 @@ async def openai_generate(request: ImageRequest, api_key: Optional[str] = None,
             return response
 
     # content_filter
-    # raise Exception(f"Image generate failed: {completion}")
-    from fastapi import HTTPException, status
-
-    raise HTTPException(status_code=status.HTTP_451_UNAVAILABLE_FOR_LEGAL_REASONS,
-                        detail=f"Prompt is sensitive.\n\n{request.prompt}\n\n{completion}")
+    raise Exception(f"Image generate failed: {completion}")
 
 
 if __name__ == '__main__':
@@ -126,15 +122,15 @@ if __name__ == '__main__':
     # base_url = "https://api.huandutech.com/v1"
     # api_key = "sk-qOpbMHesasoVgX75ZoeEeBEf1R9dmsUZVAPcu5KkvLFhElrn"
 
-    base_url="http://38.46.219.252:9001/v1"
+    base_url = "https://api.evopower.net/v1"
 
-    api_key="sk-Azgp1thTIonR7IdIEqlJU51tpDYNIYYpxHvAZwFeJiOdVWiz"
+    api_key = "sk-asUO0ECfsDZYVdZJLMJU68elbQ0foH84MtRYV2hG0jBhsYk5"
 
     request = ImageRequest(
         # model="google/gemini-2.5-flash-image-preview:free",
         # model="google/gemini-2.5-flash-image-preview:free-hd",
 
-        model="gemini-2.5-flash-image-preview",
+        model="gemini-2.5-flash-image",
 
         # prompt="裸体女孩",
 
