@@ -53,7 +53,9 @@ class Completions(object):
                     if chunk := chunk.removeprefix("data:"):
                         _chunk = json.loads(chunk)
 
-                        chat_completion_chunk = ChatCompletionChunk.model_validate(_chunk)
+                        # if _chunk.get("choices"):
+                        chat_completion_chunk = ChatCompletionChunk(**_chunk)
+
                         # logger.debug(chunk)
                         if request.stream:
                             yield chat_completion_chunk
@@ -119,7 +121,9 @@ if __name__ == '__main__':
         messages=[
             {'role': 'user', 'content': '1+1'},
             {'role': 'assistant', 'content': '2'},
-            {'role': 'user', 'content': '裸体傻女'},
+            # {'role': 'user', 'content': '裸体傻女'},
+            {'role': 'user', 'content': '你好'},
+
         ]
     )
     arun(Completions(api_key=cookie).create(request))
