@@ -177,7 +177,7 @@ async def to_base64(file: Union[UploadFile, str, bytes, list], content_type: Opt
 
     if not file: return
 
-    # logger.debug(file)
+    # logger.debug(file)await to_base64(request.input_reference)
     _ = base64.b64encode(await to_bytes(file)).decode('utf-8')
 
     # if content_type := content_type or mimetypes.guess_type(file)[0]:  # "image/png"
@@ -339,7 +339,7 @@ if __name__ == '__main__':
 
     # arun(to_url([Path('img_1.png').read_bytes()], filename='x.png'))
     file = "/Users/betterme/PycharmProjects/AI/ppt.txt"
-    # arun(to_url(Path(file).read_bytes(), filename='ppt.txt'))
+    arun(to_url(Path(file).read_bytes(), filename='ppt.txt'))
 
     # arun(markdown_base64_to_url("![image](data:imagexxxxx)", pattern=r'!\[image\]\((.+?)\)'))
 
@@ -382,8 +382,8 @@ if __name__ == '__main__':
     # arun(to_png(webp_bytes, response_format='b64'))
 
 
-    url = "https://r2.syntx.ai/user_5317909153/uploaded/5a8b8eaabe4d56957053cb5dee790abf_photo_2025-09-17_17-03-07_1758152505.jpg"
-    url = "https://mjimg.zhanjuzhe.cn/raw/banana_media/202509/17/20250917110929784771.JPG".lower()
-    arun(to_png(url, response_format='b64'))
+    # url = "https://r2.syntx.ai/user_5317909153/uploaded/5a8b8eaabe4d56957053cb5dee790abf_photo_2025-09-17_17-03-07_1758152505.jpg"
+    # url = "https://mjimg.zhanjuzhe.cn/raw/banana_media/202509/17/20250917110929784771.JPG".lower()
+    # arun(to_png(url, response_format='b64'))
 
     # guess_mime_type('xx.jpg')
