@@ -47,8 +47,30 @@ def size2aspect_ratio(size):
         return size
 
 
+def size2resolution(size) -> str:
+    """
+    把任意分辨率换算成最接近的 *p 格式。
+    返回 '720p' / '1080p' / '1440p' / '2160p' / '4320p' / '?p'
+    """
+    w, h = map(int, size.split("x"))
+
+    # 只需看高度；常见档位
+    standards = (480, 512, 720, 1080, 1440, 2160, 4320)
+    # 找到与 h 最接近的那个
+    closest = min(standards, key=lambda x: abs(x - h))
+    # 允许 10% 误差，否则认为非常规
+    if abs(closest - h) / closest > 0.15:
+        return f'{h}p'  # 非标准，直接返回原始高度
+    return f'{closest}p'
+
+
 if __name__ == '__main__':
     print(size2aspect_ratio("1920x1080"))
     print(size2aspect_ratio("1920:1080"))
     print(size2aspect_ratio("1024x1024"))
     print(size2aspect_ratio("16:9"))
+
+    print(size2resolution("512x512"))
+    print(size2resolution("480x480"))
+    print(size2resolution("1674x1238"))
+    print(size2resolution("960x528"))
