@@ -10,7 +10,7 @@
 
 
 from meutils.pipe import *
-from meutils.str_utils.regular_expression import parse_url, parse_command_string
+from meutils.str_utils.regular_expression import parse_url, parse_command_string, parse_base64
 from meutils.request_utils.crawler import Crawler
 from urllib.parse import urlencode, parse_qs, parse_qsl, quote_plus, unquote_plus, urljoin
 
